slidingpuzzle package
=====================

.. automodule:: slidingpuzzle
   :members:
   :undoc-members:

Subpackages
-----------

.. toctree::
   :maxdepth: 1

   slidingpuzzle.nn

Submodules
----------

slidingpuzzle.algorithms module
-------------------------------

.. automodule:: slidingpuzzle.algorithms
   :members:
   :undoc-members:


slidingpuzzle.board module
--------------------------

.. automodule:: slidingpuzzle.board
   :members:
   :undoc-members:

slidingpuzzle.heuristics module
-------------------------------

.. automodule:: slidingpuzzle.heuristics
   :members:
   :undoc-members:

slidingpuzzle.state module
--------------------------

.. automodule:: slidingpuzzle.state
   :members:
   :undoc-members:

